# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AppsPlaylistV0Alpha1Args', 'AppsPlaylistV0Alpha1']

@pulumi.input_type
class AppsPlaylistV0Alpha1Args:
    def __init__(__self__, *,
                 metadata: Optional[pulumi.Input['AppsPlaylistV0Alpha1MetadataArgs']] = None,
                 options: Optional[pulumi.Input['AppsPlaylistV0Alpha1OptionsArgs']] = None,
                 spec: Optional[pulumi.Input['AppsPlaylistV0Alpha1SpecArgs']] = None):
        """
        The set of arguments for constructing a AppsPlaylistV0Alpha1 resource.
        :param pulumi.Input['AppsPlaylistV0Alpha1MetadataArgs'] metadata: The metadata of the resource.
        :param pulumi.Input['AppsPlaylistV0Alpha1OptionsArgs'] options: Options for applying the resource.
        :param pulumi.Input['AppsPlaylistV0Alpha1SpecArgs'] spec: The spec of the resource.
        """
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if options is not None:
            pulumi.set(__self__, "options", options)
        if spec is not None:
            pulumi.set(__self__, "spec", spec)

    @property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input['AppsPlaylistV0Alpha1MetadataArgs']]:
        """
        The metadata of the resource.
        """
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input['AppsPlaylistV0Alpha1MetadataArgs']]):
        pulumi.set(self, "metadata", value)

    @property
    @pulumi.getter
    def options(self) -> Optional[pulumi.Input['AppsPlaylistV0Alpha1OptionsArgs']]:
        """
        Options for applying the resource.
        """
        return pulumi.get(self, "options")

    @options.setter
    def options(self, value: Optional[pulumi.Input['AppsPlaylistV0Alpha1OptionsArgs']]):
        pulumi.set(self, "options", value)

    @property
    @pulumi.getter
    def spec(self) -> Optional[pulumi.Input['AppsPlaylistV0Alpha1SpecArgs']]:
        """
        The spec of the resource.
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: Optional[pulumi.Input['AppsPlaylistV0Alpha1SpecArgs']]):
        pulumi.set(self, "spec", value)


@pulumi.input_type
class _AppsPlaylistV0Alpha1State:
    def __init__(__self__, *,
                 metadata: Optional[pulumi.Input['AppsPlaylistV0Alpha1MetadataArgs']] = None,
                 options: Optional[pulumi.Input['AppsPlaylistV0Alpha1OptionsArgs']] = None,
                 spec: Optional[pulumi.Input['AppsPlaylistV0Alpha1SpecArgs']] = None):
        """
        Input properties used for looking up and filtering AppsPlaylistV0Alpha1 resources.
        :param pulumi.Input['AppsPlaylistV0Alpha1MetadataArgs'] metadata: The metadata of the resource.
        :param pulumi.Input['AppsPlaylistV0Alpha1OptionsArgs'] options: Options for applying the resource.
        :param pulumi.Input['AppsPlaylistV0Alpha1SpecArgs'] spec: The spec of the resource.
        """
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if options is not None:
            pulumi.set(__self__, "options", options)
        if spec is not None:
            pulumi.set(__self__, "spec", spec)

    @property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input['AppsPlaylistV0Alpha1MetadataArgs']]:
        """
        The metadata of the resource.
        """
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input['AppsPlaylistV0Alpha1MetadataArgs']]):
        pulumi.set(self, "metadata", value)

    @property
    @pulumi.getter
    def options(self) -> Optional[pulumi.Input['AppsPlaylistV0Alpha1OptionsArgs']]:
        """
        Options for applying the resource.
        """
        return pulumi.get(self, "options")

    @options.setter
    def options(self, value: Optional[pulumi.Input['AppsPlaylistV0Alpha1OptionsArgs']]):
        pulumi.set(self, "options", value)

    @property
    @pulumi.getter
    def spec(self) -> Optional[pulumi.Input['AppsPlaylistV0Alpha1SpecArgs']]:
        """
        The spec of the resource.
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: Optional[pulumi.Input['AppsPlaylistV0Alpha1SpecArgs']]):
        pulumi.set(self, "spec", value)


@pulumi.type_token("grafana:experimental/appsPlaylistV0Alpha1:AppsPlaylistV0Alpha1")
class AppsPlaylistV0Alpha1(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 metadata: Optional[pulumi.Input[Union['AppsPlaylistV0Alpha1MetadataArgs', 'AppsPlaylistV0Alpha1MetadataArgsDict']]] = None,
                 options: Optional[pulumi.Input[Union['AppsPlaylistV0Alpha1OptionsArgs', 'AppsPlaylistV0Alpha1OptionsArgsDict']]] = None,
                 spec: Optional[pulumi.Input[Union['AppsPlaylistV0Alpha1SpecArgs', 'AppsPlaylistV0Alpha1SpecArgsDict']]] = None,
                 __props__=None):
        """
        Manages Grafana playlists using the new Grafana APIs.

        * [Official documentation](https://grafana.com/docs/grafana/latest/dashboards/create-manage-playlists/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/apis/)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['AppsPlaylistV0Alpha1MetadataArgs', 'AppsPlaylistV0Alpha1MetadataArgsDict']] metadata: The metadata of the resource.
        :param pulumi.Input[Union['AppsPlaylistV0Alpha1OptionsArgs', 'AppsPlaylistV0Alpha1OptionsArgsDict']] options: Options for applying the resource.
        :param pulumi.Input[Union['AppsPlaylistV0Alpha1SpecArgs', 'AppsPlaylistV0Alpha1SpecArgsDict']] spec: The spec of the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AppsPlaylistV0Alpha1Args] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages Grafana playlists using the new Grafana APIs.

        * [Official documentation](https://grafana.com/docs/grafana/latest/dashboards/create-manage-playlists/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/apis/)

        :param str resource_name: The name of the resource.
        :param AppsPlaylistV0Alpha1Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AppsPlaylistV0Alpha1Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 metadata: Optional[pulumi.Input[Union['AppsPlaylistV0Alpha1MetadataArgs', 'AppsPlaylistV0Alpha1MetadataArgsDict']]] = None,
                 options: Optional[pulumi.Input[Union['AppsPlaylistV0Alpha1OptionsArgs', 'AppsPlaylistV0Alpha1OptionsArgsDict']]] = None,
                 spec: Optional[pulumi.Input[Union['AppsPlaylistV0Alpha1SpecArgs', 'AppsPlaylistV0Alpha1SpecArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AppsPlaylistV0Alpha1Args.__new__(AppsPlaylistV0Alpha1Args)

            __props__.__dict__["metadata"] = metadata
            __props__.__dict__["options"] = options
            __props__.__dict__["spec"] = spec
        super(AppsPlaylistV0Alpha1, __self__).__init__(
            'grafana:experimental/appsPlaylistV0Alpha1:AppsPlaylistV0Alpha1',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            metadata: Optional[pulumi.Input[Union['AppsPlaylistV0Alpha1MetadataArgs', 'AppsPlaylistV0Alpha1MetadataArgsDict']]] = None,
            options: Optional[pulumi.Input[Union['AppsPlaylistV0Alpha1OptionsArgs', 'AppsPlaylistV0Alpha1OptionsArgsDict']]] = None,
            spec: Optional[pulumi.Input[Union['AppsPlaylistV0Alpha1SpecArgs', 'AppsPlaylistV0Alpha1SpecArgsDict']]] = None) -> 'AppsPlaylistV0Alpha1':
        """
        Get an existing AppsPlaylistV0Alpha1 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['AppsPlaylistV0Alpha1MetadataArgs', 'AppsPlaylistV0Alpha1MetadataArgsDict']] metadata: The metadata of the resource.
        :param pulumi.Input[Union['AppsPlaylistV0Alpha1OptionsArgs', 'AppsPlaylistV0Alpha1OptionsArgsDict']] options: Options for applying the resource.
        :param pulumi.Input[Union['AppsPlaylistV0Alpha1SpecArgs', 'AppsPlaylistV0Alpha1SpecArgsDict']] spec: The spec of the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AppsPlaylistV0Alpha1State.__new__(_AppsPlaylistV0Alpha1State)

        __props__.__dict__["metadata"] = metadata
        __props__.__dict__["options"] = options
        __props__.__dict__["spec"] = spec
        return AppsPlaylistV0Alpha1(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def metadata(self) -> pulumi.Output[Optional['outputs.AppsPlaylistV0Alpha1Metadata']]:
        """
        The metadata of the resource.
        """
        return pulumi.get(self, "metadata")

    @property
    @pulumi.getter
    def options(self) -> pulumi.Output[Optional['outputs.AppsPlaylistV0Alpha1Options']]:
        """
        Options for applying the resource.
        """
        return pulumi.get(self, "options")

    @property
    @pulumi.getter
    def spec(self) -> pulumi.Output[Optional['outputs.AppsPlaylistV0Alpha1Spec']]:
        """
        The spec of the resource.
        """
        return pulumi.get(self, "spec")

