# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetLoadTestsLoadTestResult',
    'GetProjectsProjectResult',
]

@pulumi.output_type
class GetLoadTestsLoadTestResult(dict):
    def __init__(__self__, *,
                 baseline_test_run_id: builtins.str,
                 created: builtins.str,
                 id: builtins.str,
                 name: builtins.str,
                 project_id: builtins.str,
                 script: builtins.str,
                 updated: builtins.str):
        pulumi.set(__self__, "baseline_test_run_id", baseline_test_run_id)
        pulumi.set(__self__, "created", created)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "script", script)
        pulumi.set(__self__, "updated", updated)

    @property
    @pulumi.getter(name="baselineTestRunId")
    def baseline_test_run_id(self) -> builtins.str:
        return pulumi.get(self, "baseline_test_run_id")

    @property
    @pulumi.getter
    def created(self) -> builtins.str:
        return pulumi.get(self, "created")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> builtins.str:
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter
    def script(self) -> builtins.str:
        return pulumi.get(self, "script")

    @property
    @pulumi.getter
    def updated(self) -> builtins.str:
        return pulumi.get(self, "updated")


@pulumi.output_type
class GetProjectsProjectResult(dict):
    def __init__(__self__, *,
                 created: builtins.str,
                 grafana_folder_uid: builtins.str,
                 id: builtins.str,
                 is_default: builtins.bool,
                 name: builtins.str,
                 updated: builtins.str):
        pulumi.set(__self__, "created", created)
        pulumi.set(__self__, "grafana_folder_uid", grafana_folder_uid)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_default", is_default)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "updated", updated)

    @property
    @pulumi.getter
    def created(self) -> builtins.str:
        return pulumi.get(self, "created")

    @property
    @pulumi.getter(name="grafanaFolderUid")
    def grafana_folder_uid(self) -> builtins.str:
        return pulumi.get(self, "grafana_folder_uid")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> builtins.bool:
        return pulumi.get(self, "is_default")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def updated(self) -> builtins.str:
        return pulumi.get(self, "updated")


